@@ -68,9 +68,9 @@ class PlotDataObject(DessiaObject):
         """
         type_ = dict_['type_']
         object_class = TYPE_TO_CLASS[type_]
-
-        dict_['object_class'] = full_classname(object_class)
-        return DessiaObject.dict_to_object(dict_=dict_)
+        dict_['object_class'] = full_classname(object_=object_class,
+                                               compute_for='class')
+        return DessiaObject.dict_to_object(dict_=dict_, force_generic=True)
 
 
 # class ColorMapSet(DessiaObject):
@@ -590,6 +590,20 @@ class Graph2D(PlotDataObject):
             self.axis = axis
         PlotDataObject.__init__(self, type_='graph2d', name=name)
 
+    def mpl_plot(self):
+        # axs = plt.subplots(len(self.graphs))
+        _, ax = plt.subplots()
+        xname, yname = self.to_disp_attribute_names[:2]
+        for dataset in self.graphs:
+            x = []
+            y = []
+            for element in dataset.elements:
+                x.append(element[xname])
+                y.append(element[yname])
+            ax.plot(x, y)
+        ax.set_xlabel(xname)
+        ax.set_ylabel(yname)
+        return ax
 
 class Scatter(PlotDataObject):
     """
